#!/usr/bin/env bash

export TOP_PID=$$
trap 'exit 1' TERM
function exit_script() {
  kill -s TERM $TOP_PID
  exit 0
}

function msg_box() {
  whiptail --title "$1" --msgbox "$2" 8 78 3>&1 1>&2 2>&3
}

function error_msg() {
  msg_box "错误" "$1"
}

function input_box() {
  local title="$1"
  local text="$2"
  local dft_value="$3"
  whiptail --inputbox "$text" 8 39 "$dft_value" --title "$title" 3>&1 1>&2 2>&3
}

function enum_box() {
  local title="$1"
  local text="$2"
  xargs whiptail --title "$title" --menu "$text" 25 78 16 3>&1 1>&2 2>&3
}

function yes_no_box() {
  local title="$1"
  local text="$2"
  if (whiptail --title "$title" --yesno "$text" 8 78 3>&1 1>&2 2>&3); then
    return 0
  else
    return 1
  fi
}

function when_empty_retry() {
  # shellcheck disable=SC2155
  local v="$(eval "$*")"
  local exit_code=$?
  while [ -z "$v" ]; do
    if [ $exit_code -ne 0 ]; then
      if ! yes_no_box "取消输入" "是否继续进行安装步骤"; then
        exit_script
      fi
    fi

    if ! yes_no_box "没有输入值" "是否继续进行安装步骤"; then
      exit_script
    fi

    v="$(eval "$*")"
  done

  echo "$v"
}

function super_visor_config() {
  local name="$1"
  local workdir="$2"
  local run_cmd="$3"
  eval "cat <<EOF
[program:$name]
# 程序的启动目录
directory = $workdir
#启动命令
command = $run_cmd
#随supervisord自动启动
autostart = true
#启动 5 秒后没有异常退出，就当作已经正常启动了
startsecs = 5
#自动重启
autorestart = true
#启动失败自动重试次数
startretries = 3
#用户身份
user = root
#把 stderr 重定向到 stdout
redirect_stderr = true
#stdout 文件大小
stdout_logfile_maxbytes = 20MB
#stdout 文件备份数量
stdout_logfile_backups = 20
#stdout 文件路径
stdout_logfile = $workdir/stdout.log
EOF"
}

function install_super_visor() {
  local name="$1"
  local workdir="$2"
  local run_cmd="$3"

  super_visor_config "$name" "$workdir" "run_cmd" >"/etc/supervisord.d/${name}.ini"
}

function contain_from_file() {
  local f="$1"
  local txt="$2"

  grep -E "^${txt}" "$f" &>/dev/null
}

function append_or_modify() {
  local f="$1"
  local match="$2"
  # sed 模式匹配
  local append_match="$3"
  local value="$4"

  if contain_from_file "$f" "$match"; then
    eval "sed -i \"/^${match}/ c ${value}\" '$f'"
  else
    eval "sed -i \"${append_match} a ${value}\" '$f'"
  fi
}

function start_service() {
  local name="$1"
  if ! systemctl status "${name}" &>/dev/null; then
    systemctl start "${name}"
  fi
}

function create_dbh() {
  local db_name="$1"

  eval "su postgres <<EOF1
eval 'psql <<EOF2
create database ${db_name};
EOF2'
EOF1"
}

