#!/usr/bin/env bash

source common.sh

# 检查环境
# note: 依赖第三方工具yq，用于修改yaml文件 https://github.com/mikefarah/yq
files=(
  "./yq"
  "./srv-cdnmgr"
  "./configs/config.yaml"
  "./share/ip/data_ip.dat"
  "./share/ua/ua.yaml"
)

# shellcheck disable=SC2068
for f in ${files[@]}; do
  if ! [ -f "$f" ]; then
    error_msg "错误的环境: 缺失$f 文件"
    exit 3
  fi
done

if [ $(id -u) -ne 0 ]; then
  error_msg "必须使用root 用户执行"
  exit 3
fi

# 需要配置的属性

# 数据库相关配置
#config_db_host=$(when_empty_retry input_box '数据库相关配置' "主机地址" '127.0.0.1')
#config_db_user=$(when_empty_retry input_box '数据库相关配置' '用户名' 'postgres')
#config_db_passwd=$(when_empty_retry input_box '数据库相关配置' '密码')
#config_db_db_name="$(when_empty_retry input_box '数据库相关配置' '数据库名字' 'cdn')"

# 节点通信相关配置
config_node_log_report_host=$(when_empty_retry input_box '节点通信相关配置' '节点上报日志地址，cdndcs地址')
config_node_mgr_ip=$(when_empty_retry input_box '节点通信相关配置' '本服务对外ip地址')

# 大数据相关配置
config_bigdata_call_addr=""
if yes_no_box '大数据相关配置' '是否需要启动大数据'; then
  config_bigdata_call_addr=$(when_empty_retry input_box '大数据相关配置' '大数据接口地址')
fi

# rabbitMQ配置
config_rabbitMQ_addr=$(when_empty_retry input_box 'rabbitMQ配置' '连接地址')

# 开始应用配置文件
cp configs/config.yaml config.apply.yaml
./yq -i ".dbConfig.host = \"127.0.0.1\"" config.apply.yaml
./yq -i ".dbConfig.user = \"postgres\"" config.apply.yaml
./yq -i ".dbConfig.password = \"$pg_passwd\"" config.apply.yaml
./yq -i ".dbConfig.dbName = \"cdnmgr\"" config.apply.yaml

./yq -i ".ats.logReportHost = \"$config_node_log_report_host\"" config.apply.yaml
./yq -i ".ats.mgrIp = \"$config_node_mgr_ip\"" config.apply.yaml

./yq -i ".rabbitMQ.url = \"$config_rabbitMQ_addr\"" config.apply.yaml

./yq -i ".bigdata.baseUrl = \"$config_bigdata_call_addr\"" config.apply.yaml

# 询问安装位置
install_site=$(when_empty_retry input_box "安装相关配置", "安装位置", "/home/srv-cdnmgr")
if yes_no_box "安装相关配置" "是否开始安装，安装到: $install_site"; then
  # 拷贝二进制文件
  install -D --mode=0751 srv-cdnmgr "$install_site/srv-cdnmgr" || {
    error_msg "拷贝二进制文件错误"
    exit 2
  }

  # 拷贝配置文件
  install -D --mode=0644 config.apply.yaml "$install_site/configs/config.yaml" || {
    error_msg "拷贝配置文件错误"
    exit 2
  }

  #   拷贝ip库
  #  install -D --mode=0644 data_ip_20220305_world.dat \
  #    "$install_site/pkg/resource/data_ip_20220305_world.dat" || {
  #    error_msg "拷贝ip库文件错误"
  #    exit 2
  #  }
  #
  #  # 拷贝ua库
  #  install -D --mode=0644 ua.yaml \
  #    "$install_site/pkg/resource/ua.yaml" || {
  #    error_msg "拷贝ua文件错误"
  #    exit 2
  #  }

  cp -r share "$install_site" || {
    error_msg "拷贝share文件失败"
    exit 2
  }

  # 询问是否要安装到supervisord
  if yes_no_box '安装相关配置' '是否需要自动配置supervisord'; then
    install_super_visor 'srv-cdnmgr' "$install_site" "${install_site}/srv-cdnmgr -conf configs/config.yaml" || {
      error_msg "安装supervisord配置文件失败"
      exit 2
    }

    supervisorctl update && supervisorctl restart srv-cdnmgr || {
      error_msg "启动服务失败"
      exit 2
    }
  fi

fi
