#!/usr/bin/env bash

# 加载有库
source common.sh

# 启用安装数据库
source install_pg.sh

# 启用安装消息队列
source install_rabbit_mq.sh

# 检查环境
# note: 依赖第三方工具yq，用于修改yaml文件 https://github.com/mikefarah/yq
files=(
  "./yq"
  "./srv-cdnmgr"
  "./configs/config.yaml"
  "./share/ip/data_ip.dat"
  "./share/ua/ua.yaml"
)

# shellcheck disable=SC2068
for f in ${files[@]}; do
  if ! [ -f "$f" ]; then
    error_msg "错误的环境: 缺失$f 文件"
    exit 3
  fi
done

chmod a+x ./yq

# 大数据相关配置
config_bigdata_call_addr=""
if yes_no_box '大数据相关配置' '是否需要启动大数据'; then
  config_bigdata_call_addr=$(when_empty_retry input_box '大数据相关配置' '大数据接口地址')
fi

mgr_ip_addr="$(when_empty_retry input_box '配置' '管理端对外ip地址')"
mgr_conn_rabbit_url=$(printf 'amqp://%s:%s@127.0.0.1:5672/%s' "${mq_username}" "${mq_passwd}" "${vhost_name}")

# 开始应用配置文件
cp configs/config.yaml config.apply.yaml
./yq -i ".dbConfig.host = \"127.0.0.1\"" config.apply.yaml
./yq -i ".dbConfig.user = \"postgres\"" config.apply.yaml
./yq -i ".dbConfig.password = \"$pg_passwd\"" config.apply.yaml
./yq -i ".dbConfig.dbName = \"$dft_db_name\"" config.apply.yaml

./yq -i ".ats.logReportHost = \"${mgr_ip_addr}:10009\"" config.apply.yaml
./yq -i ".ats.mgrIp = \"${mgr_ip_addr}\"" config.apply.yaml
./yq -i ".ats.mgrDomain = \"\"" config.apply.yaml

./yq -i ".rabbitMQ.url = \"${mgr_conn_rabbit_url}\"" config.apply.yaml

./yq -i ".bigdata.baseUrl = \"$config_bigdata_call_addr\"" config.apply.yaml

# 询问安装位置
#install_site=$(when_empty_retry input_box "安装相关配置", "安装位置", "/home/srv-cdnmgr")
#if yes_no_box "安装相关配置" "是否开始安装，安装到: $install_site"; then
#  # 拷贝二进制文件
#  install -D --mode=0751 srv-cdnmgr "$install_site/srv-cdnmgr" || {
#    error_msg "拷贝二进制文件错误"
#    exit 2
#  }
#
#  # 拷贝配置文件
#  install -D --mode=0644 config.apply.yaml "$install_site/configs/config.yaml" || {
#    error_msg "拷贝配置文件错误"
#    exit 2
#  }
#
#  cp -r share "$install_site" || {
#    error_msg "拷贝share文件失败"
#    exit 2
#  }
#
#  # 询问是否要安装到supervisord
#  if yes_no_box '安装相关配置' '是否需要自动配置supervisord'; then
#    install_super_visor 'srv-cdnmgr' "$install_site" "${install_site}/srv-cdnmgr -conf configs/config.yaml" || {
#      error_msg "安装supervisord配置文件失败"
#      exit 2
#    }
#
#    supervisorctl update && supervisorctl restart srv-cdnmgr || {
#      error_msg "启动服务失败"
#      exit 2
#    }
#  fi
#
#fi

install_site=/home/srv-cdnmgr
# 拷贝二进制文件
install -D --mode=0751 srv-cdnmgr "$install_site/srv-cdnmgr" || {
  error_msg "拷贝二进制文件错误"
  exit 2
}

# 拷贝配置文件
install -D --mode=0644 config.apply.yaml "$install_site/configs/config.yaml" || {
  error_msg "拷贝配置文件错误"
  exit 2
}

cp -r share "$install_site" || {
  error_msg "拷贝share文件失败"
  exit 2
}

# 询问是否要安装到supervisord
if yes_no_box '安装相关配置' '是否需要自动配置supervisord'; then
  install_super_visor 'srv-cdnmgr' "$install_site" "${install_site}/srv-cdnmgr -conf configs/config.yaml" || {
    error_msg "安装supervisord配置文件失败"
    exit 2
  }

  supervisorctl update && supervisorctl restart srv-cdnmgr || {
    error_msg "启动服务失败"
    exit 2
  }
fi
