#!/usr/bin/env bash

source common.sh

if [ $(id -u) -ne 0 ]; then
  error_msg "必须使用root 用户执行"
  exit 3
fi

if ! rpm -q postgresql14-server || ! rpm -q postgresql14-contrib; then
  if ! yes_no_box '安装pg数据库' '当前系统没有安装pg数据，是否需要安装'; then
    exit 3
  fi

  yum install -y \
    https://download.postgresql.org/pub/repos/yum/reporpms/EL-7-x86_64/pgdg-redhat-repo-latest.noarch.rpm

  if ! rpm -q postgresql14-server; then
    yum install -y postgresql14-server || {
      error_msg '安装postgresql14-server 失败'
      exit 2
    }
  fi

  if ! rpm -q postgresql14-contrib; then
    yum install -y postgresql14-contrib || {
      error_msg '安装postgresql14-contrib 失败'
      exit 2
    }
  fi
fi

pg_data="$(when_empty_retry input_box '配置pg' '配置存储路径' '/home/psql14')"
pg_server_file='/usr/lib/systemd/system/postgresql-14.service'
pg_data_env="Environment=PGDATA=${pg_data}"

# 设置PGDATA
if ! contain_from_file "$pg_server_file" "$pg_data_env"; then
  # 存在PGDATA 配置直接替换
  append_or_modify "$pg_server_file" 'Environment=PGDATA=' '/[Service]/' "$pg_data_env"
  #  if contain_from_file "$pg_server_file" 'Environment=PGDATA='; then
  #    eval "sed -i '/^Environment=PGDATA=/ c ${pg_data_env}' ${pg_server_file}"
  #  else
  #    eval "sed -i '/[Service]/ a ${pg_data_env}' ${pg_server_file}"
  #  fi
  systemctl daemon-reload

  if ! contain_from_file "$pg_server_file" "$pg_data_env"; then
    error_msg '设置PGDATA 失败'
    exit 2
  fi
fi

sleep 1

/usr/pgsql-14/bin/postgresql-14-setup initdb || {
  error_msg '初始化pg 失败'
  exit 2
}

start_service postgresql-14 || {
  error_msg '重启pg 失败'
  exit 2
}

# 配置数据库密码
if yes_no_box '配置pg' '配置数据库连接密码'; then
  pg_passwd=$(when_empty_retry input_box '配置pg' '数据库密码')
  eval "su postgres <<EOF1
eval \"psql <<EOF2
alter user postgres with password '${pg_passwd}';
EOF2\"
EOF1"
fi

# 配置网络
pg_network_config="${pg_data}/postgresql.conf"
pg_network_config2="${pg_data}/pg_hba.conf"
if yes_no_box '配置pg' '配置网络'; then
  if yes_no_box '配置网络' '是否允许外网连接'; then
    append_or_modify "${pg_network_config}" 'listen_addresses' '1' "listen_addresses = \'*\'"
    append_or_modify "${pg_network_config}" 'max_connections' '1' "max_connections = 1000"
    append_or_modify "${pg_network_config2}" 'host\s+all\s+all\s+0.0.0.0/0' '$' 'host all all 0.0.0.0/0 md5'
  fi

  if yes_no_box '配置pg' '是否开放端口'; then
    firewall-cmd --zone=public --add-port=5432/tcp --permanent
    systemctl restart firewalld.service
  fi

  systemctl restart postgresql-14 || {
    error_msg '重启pg 失败'
    exit 2
  }
fi

# 是否预先创建数据库
#if yes_no_box '配置pg' '是否创建数据库'; then
#  pg_pre_db="$(when_empty_retry input_box '配置pg' '数据库名称', 'cdn')"
#  create_dbh "$pg_pre_db"
#fi

dft_db_name='cdnmgr'

create_dbh "$dft_db_name"
