#!/usr/bin/env bash

source common.sh

files=(
  "advanced.config"
  "rabbitmq.conf"
  "rabbitmq.repo"
)

# shellcheck disable=SC2068
for f in ${files[@]}; do
  if ! [ -f "$f" ]; then
    error_msg "错误的环境: 缺失$f 文件"
    exit 3
  fi
done

if [ $(id -u) -ne 0 ]; then
  error_msg "必须使用root 用户执行"
  exit 3
fi

install rabbitmq.repo /etc/yum.repos.d || {
  error_msg "拷贝rabbitmq.repo 文件失败"
  exit 3
}

# 更新源
#yum update -y

# 安装
yum install socat logrotate -y
yum install erlang rabbitmq-server -y

install -D rabbitmq.conf /etc/rabbitmq || {
  error_msg "拷贝rabbitmq.conf 文件失败"
  exit 3
}

install -D advanced.config /etc/rabbitmq || {
  error_msg "拷贝advanced.config 文件失败"
  exit 3
}

systemctl enable rabbitmq-server
systemctl restart rabbitmq-server || {
  error_msg "启动rabbitmq 失败"
  exit 3
}
rabbitmq-plugins enable rabbitmq_management

mq_username="$(when_empty_retry input_box '配置rabbitmq' '用户名')"
mq_passwd="$(when_empty_retry input_box '配置rabbitmq' '密码')"

rabbitmqctl add_user "${mq_username}" "${mq_passwd}" || {
  error_msg "添加用户失败1"
  exit 3
}

rabbitmqctl set_user_tags "${mq_username}" administrator || {
  error_msg "添加用户失败2"
  exit 3
}

#if yes_no_box '配置rabbitmq' '是否创建vhost'; then
#  vhost_name="$(when_empty_retry input_box '配置rabbitmq' 'vhost名字' 'vhost_1')"
#  rabbitmqctl add_vhost "${vhost_name}" || {
#    error_msg "创建vhost: ${vhost_name}"
#    exit 3
#  }
#
#  rabbitmqctl set_permissions -p "${vhost_name}" "${mq_username}" ".*" ".*" ".*" || {
#    error_msg "搜权vhost: ${vhost_name}"
#    exit 3
#  }
#fi

vhost_name='vhost_1'
rabbitmqctl add_vhost "${vhost_name}" || {
  error_msg "创建vhost: ${vhost_name}"
  exit 3
}

rabbitmqctl set_permissions -p "${vhost_name}" "${mq_username}" ".*" ".*" ".*" || {
  error_msg "搜权vhost: ${vhost_name}"
  exit 3
}
